@@ -177,9 +177,9 @@ do_mount (GVfsBackend *backend,
   GSource *source;
   NfsSource *nfs_source;
   struct exportnode *export_list, *ptr;
-  const char *host;
+  const char *host, *debug;
   char *basename, *display_name, *export = NULL;
-  int err;
+  int err, debug_val;
   size_t pathlen = strlen (mount_spec->mount_prefix);
   size_t exportlen = SIZE_MAX;
   static GSourceFuncs nfs_source_callbacks = {
@@ -247,6 +247,15 @@ do_mount (GVfsBackend *backend,
   mount_free_export_list (export_list);
 
   op_backend->ctx = nfs_init_context ();
+
+  debug = g_getenv ("GVFS_NFS_DEBUG");
+  if (debug)
+    debug_val = atoi (debug);
+  else
+    debug_val = 0;
+
+  nfs_set_debug (op_backend->ctx, debug_val);
+
   err = nfs_mount (op_backend->ctx, host, export);
   if (err)
     {
